==> haskell-language-javascript-0.6.0.10-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.6.0.10
id: language-javascript-0.6.0.10-LpPFSx82pEp8mijiQKNrmx
key: language-javascript-0.6.0.10-LpPFSx82pEp8mijiQKNrmx
license: BSD3
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
homepage: https://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
author: Alan Zimmerman
exposed: True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar5
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.Token
abi: d21361a1cff881981762eb59274be2e8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/language-javascript-0.6.0.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/language-javascript-0.6.0.10
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/language-javascript-0.6.0.10
hs-libraries: HSlanguage-javascript-0.6.0.10-LpPFSx82pEp8mijiQKNrmx
depends:
    array-0.5.1.1 base-4.9.0.0
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    containers-0.5.7.1 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-javascript-0.6.0.10-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-language-javascript.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: language-javascript
version: 0.6.0.10
id: language-javascript-0.6.0.10-9oFnD4PXVWdGp1AHGtZBn7
key: language-javascript-0.6.0.10-9oFnD4PXVWdGp1AHGtZBn7
license: BSD3
copyright: (c) 2010-2015 Alan Zimmerman, 2015 Erik de Castro Lopo
maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
homepage: https://github.com/erikd/language-javascript
synopsis: Parser for JavaScript
description:
    Parses Javascript into an Abstract Syntax Tree (AST).  Initially intended as frontend to hjsmin.
    .
    Note: Version 0.5.0 breaks compatibility with prior versions, the AST has been reworked to allow
    round trip processing of JavaScript.
category: Language
author: Alan Zimmerman
exposed: True
exposed-modules:
    Language.JavaScript.Parser Language.JavaScript.Parser.AST
    Language.JavaScript.Parser.Grammar5
    Language.JavaScript.Parser.Lexer Language.JavaScript.Parser.Parser
    Language.JavaScript.Parser.SrcLocation
    Language.JavaScript.Pretty.Printer
    Language.JavaScript.Process.Minify
hidden-modules: Language.JavaScript.Parser.LexerUtils
                Language.JavaScript.Parser.ParseError
                Language.JavaScript.Parser.ParserMonad
                Language.JavaScript.Parser.Token
abi: edfa7bdeb793b3dd474880f6b367926a
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/language-javascript-0.6.0.10
library-dirs: /usr/lib/ghc-8.0.2/site-local/language-javascript-0.6.0.10
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/language-javascript-0.6.0.10
hs-libraries: HSlanguage-javascript-0.6.0.10-9oFnD4PXVWdGp1AHGtZBn7
depends:
    array-0.5.1.1 base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    containers-0.5.7.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
haddock-interfaces: /usr/share/doc/haskell-language-javascript/html/language-javascript.haddock
haddock-html: /usr/share/doc/haskell-language-javascript/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
